@@ -199,10 +199,10 @@ void KfindDlg::slotResult(int errorCode)
         setStatusMsg(i18n("Canceled."));
     } else if (errorCode == KIO::ERR_MALFORMED_URL) {
         setStatusMsg(i18n("Error."));
-        KMessageBox::sorry(this, i18n("Please specify an absolute path in the \"Look in\" box."));
+        KMessageBox::error(this, i18n("Please specify an absolute path in the \"Look in\" box."));
     } else if (errorCode == KIO::ERR_DOES_NOT_EXIST) {
         setStatusMsg(i18n("Error."));
-        KMessageBox::sorry(this, i18n("Could not find the specified folder."));
+        KMessageBox::error(this, i18n("Could not find the specified folder."));
     } else {
         setStatusMsg(i18n("Error."));
     }
@@ -266,19 +266,14 @@ void KfindDlg::slotNewItems(const QString &file)
 
 QStringList KfindDlg::getAllSubdirs(QDir d)
 {
-    QStringList dirs;
-    QStringList subdirs;
-
     d.setFilter(QDir::Dirs);
-    dirs = d.entryList();
+    const QStringList dirs = d.entryList(QDir::NoDotAndDotDot);
+    QStringList subdirs;
+    subdirs.reserve(dirs.size());
 
-    const QStringList::const_iterator end(dirs.constEnd());
-    for (QStringList::const_iterator it = dirs.constBegin(); it != end; ++it) {
-        if ((*it == QLatin1String(".")) || (*it == QLatin1String(".."))) {
-            continue;
-        }
-        subdirs.append(d.path()+QLatin1Char('/')+*it);
-        subdirs += getAllSubdirs(QString(d.path()+QLatin1Char('/')+*it));
+    for (const auto &dir : dirs) {
+        subdirs.append(d.path() + QLatin1Char('/') + dir);
+        subdirs += getAllSubdirs(QDir(d.path() + QLatin1Char('/') + dir));
     }
     return subdirs;
 }
